SortMatcher

Enum SortMatcher 

pub enum SortMatcher {
    Ascending,
    Descending,
}
SortMatcher offers a flexible way to assert whether a collection is sorted in ascending or descending order.

clearcheck implements SortMatcher for collection types including vector, arrays and reference to slices.

Example

 use clearcheck::matchers::collection::sort::{be_sorted_ascending, SortMatcher};
 use clearcheck::matchers::Matcher;

 let matcher = be_sorted_ascending();
 let collection = vec!["clearcheck", "junit"];

 assert!(matcher.test(&collection).passed());

Variants



Ascending



Descending